@@ -12,7 +12,10 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 import base64
+import json
+from datetime import timedelta
 from pathlib import Path
+from typing import Optional
 
 from robot.utils import get_link_path  # type: ignore
 from robotlibcore import keyword  # type: ignore
@@ -20,7 +23,6 @@ from robotlibcore import keyword  # type: ignore
 from ..base import LibraryComponent
 from ..generated.playwright_pb2 import Request
 from ..utils import logger
-from ..utils.time_conversion import timestr_to_millisecs
 
 
 class Control(LibraryComponent):
@@ -138,31 +140,30 @@ class Control(LibraryComponent):
         return True if filename.upper() == "EMBED" else False
 
     @keyword(tags=["Setter", "Config"])
-    def set_browser_timeout(self, timeout: str) -> str:
+    def set_browser_timeout(self, timeout: timedelta) -> str:
         """Sets the timeout used by most input and getter keywords.
 
         ``timeout`` <str> Timeout of it is for current playwright context. **Required**
 
         Returns the previous value of the timeout.
         """
-        parsed_timeout = timestr_to_millisecs(timeout)
-        old_timeout = self.timeout
-        self.timeout = timeout
+        old_timeout = self.millisecs_to_timestr(self.timeout)
+        self.timeout = self.convert_timeout(timeout)
         with self.playwright.grpc_channel() as stub:
-            response = stub.SetTimeout(Request().Timeout(timeout=parsed_timeout))
+            response = stub.SetTimeout(Request().Timeout(timeout=self.timeout))
             logger.info(response.log)
         return old_timeout
 
     @keyword(tags=["Setter", "Config"])
-    def set_retry_assertions_for(self, timeout: str) -> str:
+    def set_retry_assertions_for(self, timeout: timedelta) -> str:
         """Sets the timeout used in retrying assertions when they fail.
 
         ``timeout`` <str>
 
         Returns the previous value of the retry_assertions_until.
         """
-        old_retry_assertions_for = self.retry_assertions_for
-        self.retry_assertions_for = timeout
+        old_retry_assertions_for = self.millisecs_to_timestr(self.retry_assertions_for)
+        self.retry_assertions_for = self.convert_timeout(timeout)
         return old_retry_assertions_for
 
     @keyword(tags=["Setter", "BrowserControl"])
@@ -200,6 +201,23 @@ class Control(LibraryComponent):
             response = stub.SetOffline(Request().Bool(value=offline))
             logger.info(response.log)
 
+    @keyword(tags=["Setter", "BrowserControl"])
+    def set_geolocation(
+        self, latitude: float, longitude: float, accuracy: Optional[float] = None
+    ):
+        """Updated the correct Context's geolocation.
+
+        Latitude can be between -90 and 90 and longitude can be between -180 and 180.
+        """
+        geolocation_dict = {"latitude": latitude, "longitude": longitude}
+        if accuracy:
+            geolocation_dict["accuracy"] = accuracy
+        geolocation = json.dumps(geolocation_dict)
+        logger.info(geolocation)
+        with self.playwright.grpc_channel() as stub:
+            response = stub.SetGeolocation(Request().Json(body=geolocation))
+            logger.info(response.log)
+
     @keyword(tags=["Setter", "BrowserControl"])
     def reload(self):
         """Reloads current active page."""
