@@ -28,12 +28,13 @@ from ..assertion_engine import (
 )
 from ..base import LibraryComponent
 from ..generated.playwright_pb2 import Request
-from ..utils import logger
+from ..utils import exec_scroll_function, logger
 from ..utils.data_types import (
+    AreaFields,
     AssertionOperator,
     BoundingBoxFields,
     SelectAttribute,
-    ViewportFields,
+    SizeFields,
 )
 
 
@@ -44,7 +45,7 @@ class Getters(LibraryComponent):
         self,
         assertion_operator: Optional[AssertionOperator] = None,
         assertion_expected: Any = None,
-    ) -> str:
+    ) -> Any:
         """Returns the current URL.
 
         Optionally asserts that it matches the specified assertion.
@@ -66,7 +67,7 @@ class Getters(LibraryComponent):
         self,
         assertion_operator: Optional[AssertionOperator] = None,
         assertion_expected: Any = None,
-    ) -> object:
+    ) -> Any:
         """Returns page model state object as a dictionary.
 
         See `Assertions` for further details for the assertion arguments. Defaults to None.
@@ -93,7 +94,7 @@ class Getters(LibraryComponent):
         self,
         assertion_operator: Optional[AssertionOperator] = None,
         assertion_expected: Any = None,
-    ) -> str:
+    ) -> Any:
         """Gets pages HTML source as a string.
 
         Optionally does a string assertion.
@@ -114,7 +115,7 @@ class Getters(LibraryComponent):
         self,
         assertion_operator: Optional[AssertionOperator] = None,
         assertion_expected: Any = None,
-    ):
+    ) -> Any:
         """Returns the title of the current page.
 
         Optionally asserts that it matches the specified assertion.
@@ -135,8 +136,9 @@ class Getters(LibraryComponent):
         selector: str,
         assertion_operator: Optional[AssertionOperator] = None,
         assertion_expected: Any = None,
-    ):
+    ) -> Any:
         """Returns text attribute of the element found by ``selector``.
+        See the `Finding elements` section for details about the selectors.
 
         Optionally asserts that the text matches the specified assertion.
 
@@ -154,13 +156,14 @@ class Getters(LibraryComponent):
         property: str,
         assertion_operator: Optional[AssertionOperator] = None,
         assertion_expected: Any = None,
-    ):
+    ) -> Any:
         """Returns the ``property`` of the element found by ``selector``.
 
         Optionally asserts that the property value matches the specified
         assertion.
 
         ``selector`` <str> Selector from which the info is to be retrieved. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         ``property`` <str> Requested property name. **Required**
 
@@ -192,13 +195,14 @@ class Getters(LibraryComponent):
         attribute: str,
         assertion_operator: Optional[AssertionOperator] = None,
         assertion_expected: Any = None,
-    ):
+    ) -> Any:
         """Returns the HTML ``attribute`` of the element found by ``selector``.
 
         Optionally asserts that the attribute value matches the specified
         assertion.
 
         ``selector`` <str> Selector from which the info is to be retrieved. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         ``attribute`` <str> Requested attribute name. **Required**
 
@@ -239,12 +243,13 @@ class Getters(LibraryComponent):
         selector: str,
         assertion_operator: Optional[AssertionOperator] = None,
         *assertion_expected,
-    ):
+    ) -> Any:
         """Returns all HTML attribute names of an element as a list.
 
         Optionally asserts that these match the specified assertion.
 
         ``selector`` <str> Selector from which the info is to be retrieved. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         ``assertion_operator`` <AssertionOperator> See `Assertions` for further details. Defaults to None.
 
@@ -269,12 +274,13 @@ class Getters(LibraryComponent):
         selector: str,
         assertion_operator: Optional[AssertionOperator] = None,
         *assertion_expected,
-    ):
+    ) -> Any:
         """Returns all classes of an element as a list.
 
         Optionally asserts that the value matches the specified assertion.
 
         ``selector`` <str> Selector from which the info is to be retrieved. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         ``assertion_operator`` <AssertionOperator> See `Assertions` for further details. Defaults to None.
 
@@ -300,12 +306,13 @@ class Getters(LibraryComponent):
         selector: str,
         assertion_operator: Optional[AssertionOperator] = None,
         assertion_expected: Any = None,
-    ):
+    ) -> Any:
         """Returns value of the textfield found by ``selector``.
 
         Optionally asserts that the value matches the specified assertion.
 
         ``selector`` <str> Selector from which the info is to be retrieved. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         See `Assertions` for further details for the assertion arguments. Defaults to None.
         """
@@ -324,12 +331,13 @@ class Getters(LibraryComponent):
         option_attribute: SelectAttribute = SelectAttribute.label,
         assertion_operator: Optional[AssertionOperator] = None,
         *assertion_expected,
-    ):
+    ) -> Any:
         """Returns the specified attribute of selected options of the ``select`` element.
 
         Optionally asserts that these match the specified assertion.
 
         ``selector`` <str> Selector from which the info is to be retrieved. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         ``option_attribute`` <SelectAttribute.label> Which attribute shall be returned/verified.
         Allowed values are ``< ``value`` | ``label`` | ``text`` | ``index`` >``. Defaults to label.
@@ -382,11 +390,12 @@ class Getters(LibraryComponent):
         self,
         selector: str,
         assertion_operator: Optional[AssertionOperator] = None,
-        expected_state: str = "Unchecked",
-    ):
+        expected_state: Union[bool, str] = "Unchecked",
+    ) -> bool:
         """Returns the state of the checkbox found by ``selector``.
 
-        ``selector`` <str> Selector which shall be examined
+        ``selector`` <str> Selector which shall be examined.
+        See the `Finding elements` section for details about the selectors.
 
         Optionally asserts that the state matches the specified assertion.
 
@@ -423,12 +432,13 @@ class Getters(LibraryComponent):
         selector: str,
         assertion_operator: Optional[AssertionOperator] = None,
         expected_value: Union[int, str] = 0,
-    ):
+    ) -> Any:
         """Returns the count of elements found with ``selector``.
 
         Optionally asserts that the count matches the specified assertion.
 
         ``selector`` <str> Selector which shall be counted.
+        See the `Finding elements` section for details about the selectors.
 
         ``assertion_operator`` <AssertionOperator> See `Assertions` for further details. Defaults to None.
 
@@ -450,10 +460,10 @@ class Getters(LibraryComponent):
     @with_assertion_polling
     def get_viewport_size(
         self,
-        key: ViewportFields = ViewportFields.ALL,
+        key: SizeFields = SizeFields.ALL,
         assertion_operator: Optional[AssertionOperator] = None,
         assertion_expected: Any = None,
-    ):
+    ) -> Any:
         """Returns the current viewport dimensions.
 
         Optionally asserts that the count matches the specified assertion.
@@ -476,7 +486,7 @@ class Getters(LibraryComponent):
             logger.info(response.log)
             parsed = json.loads(response.json)
             logger.debug(parsed)
-            if key == ViewportFields.ALL:
+            if key == SizeFields.ALL:
                 return int_dict_verify_assertion(
                     parsed, assertion_operator, assertion_expected, "Viewport size is"
                 )
@@ -490,27 +500,35 @@ class Getters(LibraryComponent):
                 )
 
     @keyword(tags=["Getter", "PageContent"])
-    def get_element(self, selector: str):
+    def get_element(self, selector: str) -> str:
         """Returns a reference to a Playwright element handle.
 
         The reference can be used in subsequent selectors.
 
-        ``selector`` <str> Selector from which shall be retrieved.
-        See `library introduction` for more details on the selector syntax. **Required**
+        ``selector`` <str> Selector from which shall be retrieved **Required**.
+        See the `Finding elements` section for details about the selectors.
         """
         with self.playwright.grpc_channel() as stub:
             response = stub.GetElement(Request().ElementSelector(selector=selector))
             return response.body
 
     @keyword(tags=["Getter", "PageContent"])
-    def get_elements(self, selector: str):
+    def get_elements(self, selector: str) -> List[str]:
         """Returns a reference to playwright element handle for all matched elements by ``selector``.
 
         ``selector`` <str> Selector from which shall be retrieved. **Required**
+        See the `Finding elements` section for details about the selectors.
         """
-        with self.playwright.grpc_channel() as stub:
-            response = stub.GetElements(Request().ElementSelector(selector=selector))
-            return json.loads(response.json)
+        try:
+            with self.playwright.grpc_channel() as stub:
+                response = stub.GetElements(
+                    Request().ElementSelector(selector=selector)
+                )
+                return json.loads(response.json)
+        except AssertionError as error:
+            if "Could not find element with" in str(error):
+                return []
+            raise error
 
     @keyword(tags=["Getter", "Assertion", "PageContent"])
     @with_assertion_polling
@@ -520,12 +538,13 @@ class Getters(LibraryComponent):
         key: str = "ALL",
         assertion_operator: Optional[AssertionOperator] = None,
         assertion_expected: Any = None,
-    ):
+    ) -> Any:
         """Gets the computed style properties of the element selected by ``selector``.
 
         Optionally matches with any sequence assertion operator.
 
         ``selector`` <str> Selector from which the style shall be retrieved. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         ``key`` <str> Key of the requested CSS property. Retrieves "ALL" styles by default.
 
@@ -550,17 +569,18 @@ class Getters(LibraryComponent):
                     f"Style value for {key} is ",
                 )
 
-    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    @keyword(name="Get BoundingBox", tags=["Getter", "Assertion", "PageContent"])
     def get_boundingbox(
         self,
         selector: str,
         key: BoundingBoxFields = BoundingBoxFields.ALL,
         assertion_operator: Optional[AssertionOperator] = None,
         assertion_expected: Any = None,
-    ):
-        """Gets elements size and location as an object {x: float, y: float, width: float, height: float}.
+    ) -> Any:
+        """Gets elements size and location as an object ``{x: float, y: float, width: float, height: float}``.
 
         ``selector`` <str> Selector from which shall be retrieved. **Required**
+        See the `Finding elements` section for details about the selectors.
 
         ``key`` < ``x`` | ``y`` | ``width`` | ``height`` | ``ALL`` > Optionally filters the returned values.
         If keys is set to ``ALL``(default) it will return the BoundingBox as Dictionary,
@@ -593,5 +613,143 @@ class Getters(LibraryComponent):
                     parsed[key.name],
                     assertion_operator,
                     assertion_expected,
-                    f"{key} is ",
+                    f"BoundingBox {key.name} is ",
                 )
+
+    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    def get_scroll_size(
+        self,
+        selector: Optional[str] = None,
+        key: SizeFields = SizeFields.ALL,
+        assertion_operator: Optional[AssertionOperator] = None,
+        assertion_expected: Any = None,
+    ) -> Any:
+        """Gets elements or pages scrollable size as object ``{width: float, height: float}``.
+
+        ``selector`` <str> Optional selector from which shall be retrieved.
+        If no selector is given the scroll size of the page itself is used.
+        See the `Finding elements` section for details about the selectors.
+
+        ``key`` < ``width`` | ``height`` | ``ALL`` > Optionally filters the returned values.
+        If keys is set to ``ALL``(default) it will return the scroll size as dictionary,
+        otherwise it will just return the single value selected by the key.
+
+        See `Assertions` for further details for the assertion arguments. Defaults to None.
+
+        See `Get BoundingBox` for more similar examples.
+
+        Example use:
+        | ${height}=         Get Scroll Size    height                          # filtered page by height
+        | Log                Width: ${height}                                   # Height: 58425
+        | ${scroll_size}=    Get Scroll Size    id=keyword-shortcuts-container  # unfiltered element
+        | Log                ${scroll_size}                                     # {'width': 253, 'height': 3036}
+        """
+        scroll_size = dict()
+        scroll_size["width"] = exec_scroll_function(self, "scrollWidth", selector)
+        scroll_size["height"] = exec_scroll_function(self, "scrollHeight", selector)
+        if key == SizeFields.ALL:
+            return int_dict_verify_assertion(
+                scroll_size,
+                assertion_operator,
+                assertion_expected,
+                "Scroll size is",
+            )
+        else:
+            logger.info(f"Value of '{key}'': {scroll_size[key.name]}")
+            return float_str_verify_assertion(
+                scroll_size[key.name],
+                assertion_operator,
+                assertion_expected,
+                f"Scroll {key.name} is ",
+            )
+
+    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    def get_scroll_position(
+        self,
+        selector: Optional[str] = None,
+        key: AreaFields = AreaFields.ALL,
+        assertion_operator: Optional[AssertionOperator] = None,
+        assertion_expected: Any = None,
+    ) -> Any:
+        """Gets elements or pages current scroll position as object ``{top: float, left: float, bottom: float, right: float}``.
+
+        It describes the rectangle which is visible of the scrollable content of that element.
+        all values are measured from position {top: 0, left: 0}.
+
+        ``top`` uses js function scrollTop, ``left`` uses scrollLeft and
+        ``bottom`` and ``right`` are calculated with the client size.
+
+        ``selector`` <str> Optional selector from which shall be retrieved.
+        If no selector is given the client size of the page itself is used (``document.scrollingElement``).
+        See the `Finding elements` section for details about the selectors.
+
+        ``key`` < ``top`` | ``left`` | ``bottom`` | ``right`` | ``ALL`` > Optionally filters the returned values.
+        If keys is set to ``ALL``(default) it will return the scroll position as dictionary,
+        otherwise it will just return the single value selected by the key.
+
+        See `Assertions` for further details for the assertion arguments. Defaults to None.
+
+        See `Get BoundingBox` or `Get Scroll Size` for examples.
+        """
+        scroll_position = dict()
+        scroll_position["top"] = exec_scroll_function(self, "scrollTop", selector)
+        scroll_position["left"] = exec_scroll_function(self, "scrollLeft", selector)
+        client_size = self.get_client_size(selector)
+        scroll_position["bottom"] = scroll_position["top"] + client_size["height"]
+        scroll_position["right"] = scroll_position["left"] + client_size["width"]
+        if key == AreaFields.ALL:
+            return int_dict_verify_assertion(
+                scroll_position,
+                assertion_operator,
+                assertion_expected,
+                "Scroll position is",
+            )
+        else:
+            logger.info(f"Value of '{key}'': {scroll_position[key.name]}")
+            return float_str_verify_assertion(
+                scroll_position[key.name],
+                assertion_operator,
+                assertion_expected,
+                f"Scroll position {key.name} is ",
+            )
+
+    @keyword(tags=["Getter", "Assertion", "PageContent"])
+    def get_client_size(
+        self,
+        selector: Optional[str] = None,
+        key: SizeFields = SizeFields.ALL,
+        assertion_operator: Optional[AssertionOperator] = None,
+        assertion_expected: Any = None,
+    ) -> Any:
+        """Gets elements or pages client size (``clientHeight``, ``clientWidth``) as object {width: float, height: float}.
+
+        ``selector`` <str> Optional selector from which shall be retrieved.
+        If no selector is given the client size of the page itself is used (``document.scrollingElement``).
+        See the `Finding elements` section for details about the selectors.
+
+        ``key`` < ``width`` | ``height`` | ``ALL`` > Optionally filters the returned values.
+        If keys is set to ``ALL``(default) it will return the scroll size as dictionary,
+        otherwise it will just return the single value selected by the key.
+
+        See `Assertions` for further details for the assertion arguments. Defaults to None.
+
+        See `Get BoundingBox` or `Get Scroll Size` for examples.
+        """
+        client_size = dict()
+        client_size["width"] = exec_scroll_function(self, "clientWidth", selector)
+        client_size["height"] = exec_scroll_function(self, "clientHeight", selector)
+        if key == SizeFields.ALL:
+            return int_dict_verify_assertion(
+                client_size,
+                assertion_operator,
+                assertion_expected,
+                "Client size is",
+            )
+        else:
+            logger.info(f"Value of '{key}'': {client_size[key.name]}")
+            return float_str_verify_assertion(
+                client_size[key.name],
+                assertion_operator,
+                assertion_expected,
+                f"Client {key.name} is ",
+            )
