@@ -13,6 +13,7 @@
 # limitations under the License.
 
 import json
+from datetime import timedelta
 from pathlib import Path
 from typing import Any, Dict, Optional
 
@@ -25,7 +26,6 @@ from ..utils import (
     get_abs_scroll_coordinates,
     get_rel_scroll_coordinates,
     logger,
-    timestr_to_millisecs,
 )
 from ..utils.data_types import (
     BoundingBox,
@@ -45,7 +45,11 @@ from ..utils.data_types import (
 class Interaction(LibraryComponent):
     @keyword(tags=["Setter", "PageContent"])
     def type_text(
-        self, selector: str, text: str, delay: str = "0 ms", clear: bool = True
+        self,
+        selector: str,
+        text: str,
+        delay: timedelta = timedelta(seconds=0),
+        clear: bool = True,
     ):
         """Types the given ``text`` into the text field found by ``selector``.
 
@@ -107,7 +111,11 @@ class Interaction(LibraryComponent):
 
     @keyword(tags=["Setter", "PageContent"])
     def type_secret(
-        self, selector: str, secret: str, delay: str = "0 ms", clear: bool = True
+        self,
+        selector: str,
+        secret: str,
+        delay: timedelta = timedelta(seconds=0),
+        clear: bool = True,
     ):
         """Types the given ``secret`` into the text field found by ``selector``.
 
@@ -173,29 +181,113 @@ class Interaction(LibraryComponent):
             response = stub.Press(Request().PressKeys(selector=selector, key=keys))
             logger.debug(response.log)
 
-    @keyword(tags=["Setter", "PageContent"])
-    def click(self, selector: str):
-        """Clicks the element found by ``selector``.
-
-        ``selector`` <str> Selector of the element to click. **Required**
-        See the `Finding elements` section for details about the selectors.
-        """
-        with self.playwright.grpc_channel() as stub:
-            response = stub.Click(Request().ElementSelector(selector=selector))
-            logger.debug(response.log)
-
     @keyword(tags=["Setter", "PageContent"])
     def click_with_options(
         self,
         selector: str,
         button: MouseButton = MouseButton.left,
         clickCount: int = 1,
-        delay: Optional[str] = None,
+        delay: Optional[timedelta] = None,
         position_x: Optional[float] = None,
         position_y: Optional[float] = None,
         force: bool = False,
         noWaitAfter: bool = False,
         *modifiers: KeyboardModifier,
+    ):
+        """*DEPRECATED* Use `Click` instead."""
+        self.click(
+            selector,
+            button,
+            clickCount,
+            delay,
+            position_x,
+            position_y,
+            force,
+            noWaitAfter,
+            *modifiers,
+        )
+
+    @keyword(tags=["Setter", "PageContent"])
+    def click(
+        self,
+        selector: str,
+        button: MouseButton = MouseButton.left,
+        clickCount: int = 1,
+        delay: Optional[timedelta] = None,
+        position_x: Optional[float] = None,
+        position_y: Optional[float] = None,
+        force: bool = False,
+        noWaitAfter: bool = False,
+        *modifiers: KeyboardModifier,
+    ):
+        """Simulates mouse click on the element found by ``selector``.
+
+        This keyword clicks an element matching ``selector`` by performing the following steps:
+        - Find an element matches selector. If there is none, wait until a matching element is attached to the DOM.
+        - Wait for actionability checks on the matched element, unless ``force`` option is set. If the element is detached during the checks, the whole action is retried.
+        - Scroll the element into view if needed.
+        - Use `Mouse Button` to click in the center of the element, or the specified position.
+        - Wait for initiated navigation to either succeed or fail, unless ``noWaitAfter`` option is set.
+
+        ``selector`` <str> Selector element to click. **Required**
+        See the `Finding elements` section for details about the selectors.
+
+        ``button`` < ``left`` | ``right`` | ``middle`` > Defaults to ``left`` if invalid.
+
+        ``click_count`` <int> Defaults to 1.
+
+        ``delay`` <robot time str> Time to wait between mouse-down and mouse-up.
+        Defaults to 0.
+
+        ``position_x`` & ``position_y`` <float> A point to click relative to the
+        top-left corner of element bounding-box. Only positive values within the bounding-box are allowed.
+        If not specified, clicks to some visible point of the element.
+
+        ``force`` <bool> Set to True to skip Playwright's [https://github.com/microsoft/playwright/blob/master/docs/actionability.md | Actionability checks].
+
+        ``noWaitAfter`` <bool> Actions that initiate navigation, are waiting for
+        these navigation to happen and for pages to start loading.
+        You can opt out of waiting via setting this flag.
+        You would only need this option in the exceptional cases such as navigating
+        to inaccessible pages. Defaults to ``False``.
+
+        ``*modifiers`` < ``Alt`` | ``Control`` | ``Meta`` | ``Shift`` >
+        Modifier keys to press. Ensures that only these modifiers are pressed
+        during the click, and then restores current modifiers back.
+        If not specified, currently pressed modifiers are used.
+        """
+        with self.playwright.grpc_channel() as stub:
+            options = {
+                "button": button.name,
+                "clickCount": clickCount,
+                "force": force,
+                "noWaitAfter": noWaitAfter,
+            }
+            if delay:
+                options["delay"] = self.get_timeout(delay)
+            # Without the != None 0 being falsy causes issues
+            if position_x is not None and position_y is not None:
+                positions: Dict[str, object] = {"x": position_x, "y": position_y}
+                options["position"] = positions
+            if modifiers:
+                options["modifiers"] = [m.name for m in modifiers]
+            options_json = json.dumps(options)
+            logger.debug(f"Click options are: {options_json}")
+            response = stub.Click(
+                Request().ElementSelectorWithOptions(
+                    selector=selector, options=options_json
+                )
+            )
+            logger.debug(response.log)
+
+    @keyword(tags=["Setter", "PageContent"])
+    def hover(
+        self,
+        selector: str,
+        position_x: Optional[float] = None,
+        position_y: Optional[float] = None,
+        force: bool = False,
+        *modifiers: KeyboardModifier,
     ):
         """Moves the virtual mouse with multiple options on the element found by ``selector``.
 
@@ -224,75 +316,6 @@ class Interaction(LibraryComponent):
 
         ``force`` <bool> Set to True to skip Playwright's [https://github.com/microsoft/playwright/blob/master/docs/actionability.md | Actionability checks].
 
-        ``*modifiers`` < ``Alt`` | ``Control`` | ``Meta`` | ``Shift`` >
-        Modifier keys to press. Ensures that only these modifiers are pressed
-        during the click, and then restores current modifiers back.
-        If not specified, currently pressed modifiers are used.
-        """
-        with self.playwright.grpc_channel() as stub:
-            options = {
-                "button": button.name,
-                "clickCount": clickCount,
-                "force": force,
-                "noWaitAfter": noWaitAfter,
-            }
-            if delay:
-                options["delay"] = timestr_to_millisecs(delay)
-            # Without the != None 0 being falsy causes issues
-            if position_x is not None and position_y is not None:
-                positions: Dict[str, object] = {"x": position_x, "y": position_y}
-                options["position"] = positions
-            if modifiers:
-                options["modifiers"] = [m.name for m in modifiers]
-            options_json = json.dumps(options)
-            logger.debug(f"Click Options are: {options_json}")
-            response = stub.ClickWithOptions(
-                Request().ElementSelectorWithOptions(
-                    selector=selector, options=options_json
-                )
-            )
-            logger.debug(response.log)
-
-    @keyword(tags=["Setter", "PageContent"])
-    def hover(
-        self,
-        selector: str,
-        position_x: Optional[float] = None,
-        position_y: Optional[float] = None,
-        force: bool = False,
-        *modifiers: KeyboardModifier,
-    ):
-        """Simulates mouse click with multiple options on the element found by ``selector``.
-
-        This keyword clicks an element matching ``selector`` by performing the following steps:
-        - Find an element matches selector. If there is none, wait until a matching element is attached to the DOM.
-        - Wait for actionability checks on the matched element, unless ``force`` option is set. If the element is detached during the checks, the whole action is retried.
-        - Scroll the element into view if needed.
-        - Use `Mouse Button` to click in the center of the element, or the specified position.
-        - Wait for initiated navigation to either succeed or fail, unless ``noWaitAfter`` option is set.
-
-        ``selector`` <str> Selector element to click. **Required**
-        See the `Finding elements` section for details about the selectors.
-
-        ``button`` < ``left`` | ``right`` | ``middle`` > Defaults to ``left`` if invalid.
-
-        ``click_count`` <int> Defaults to 1.
-
-        ``delay`` <robot time str> Time to wait between mouse-down and mouse-up.
-        Defaults to 0.
-
-        ``position_x`` & ``position_y`` <int> A point to click relative to the
-        top-left corner of element bounding-box. Only positive values within the bounding-box are allowed.
-        If not specified, clicks to some visible point of the element.
-
-        ``force`` <bool> Set to True to skip Playwright's [https://github.com/microsoft/playwright/blob/master/docs/actionability.md | Actionability checks].
-
-        ``noWaitAfter`` <bool> Actions that initiate navigation, are waiting for
-        these navigation to happen and for pages to start loading.
-        You can opt out of waiting via setting this flag.
-        You would only need this option in the exceptional cases such as navigating
-        to inaccessible pages. Defaults to ``False``.
-
         ``*modifiers`` < ``Alt`` | ``Control`` | ``Meta`` | ``Shift`` >
         Modifier keys to press. Ensures that only these modifiers are pressed
         during the click, and then restores current modifiers back.
@@ -498,12 +521,12 @@ class Interaction(LibraryComponent):
         self,
         selector: str,
         text: str,
-        delay: str = "0 ms",
+        delay: timedelta = timedelta(microseconds=0),
         clear: bool = True,
         log_response: bool = True,
     ):
         with self.playwright.grpc_channel() as stub:
-            delay_ms = timestr_to_millisecs(delay)
+            delay_ms = self.get_timeout(delay)
             response = stub.TypeText(
                 Request().TypeText(
                     selector=selector, text=text, delay=int(delay_ms), clear=clear
